@@ -26,7 +26,7 @@ import webkit
 import string
 import parted
 
-gettext.install("live-installer", "/usr/share/linuxmint/locale")
+gettext.install("live-installer", "/usr/share/pearllinux/locale")
 gtk.gdk.threads_init()
 
 LOADING_ANIMATION = '/usr/share/live-installer/loading.gif'
@@ -46,8 +46,8 @@ class InstallerWindow:
     def __init__(self, fullscreen=False):
 
         #Disable the screensaver to prevent a segfault situation in GTK2
-        os.system("sudo -u mint gsettings set org.cinnamon.desktop.screensaver lock-enabled false 2> /dev/null")
-        os.system("sudo -u mint gsettings set org.mate.screensaver lock-enabled false 2> /dev/null")
+        os.system("sudo -u pearl gsettings set org.cinnamon.desktop.screensaver lock-enabled false 2> /dev/null")
+        os.system("sudo -u pearl gsettings set org.mate.screensaver lock-enabled false 2> /dev/null")
 
         #Build the Setup object (where we put all our choices)
         self.setup = Setup()
@@ -92,7 +92,7 @@ class InstallerWindow:
         self.wizard_pages[self.PAGE_CUSTOMWARNING] = WizardPage(_("Please make sure you wish to manage partitions manually"), "hdd.svg")
         self.wizard_pages[self.PAGE_ADVANCED] = WizardPage(_("Advanced options"), "advanced.png")
         self.wizard_pages[self.PAGE_OVERVIEW] = WizardPage(_("Summary"), "summary.png")
-        self.wizard_pages[self.PAGE_INSTALL] = WizardPage(_("Installing Linux Mint..."), "install.png")
+        self.wizard_pages[self.PAGE_INSTALL] = WizardPage(_("Installing Pearl Linux..."), "install.png")
         self.wizard_pages[self.PAGE_CUSTOMPAUSED] = WizardPage(_("Installation paused: please finish the custom installation"), "install.png")
 
         # set the button events (wizard_cb)
@@ -591,7 +591,7 @@ class InstallerWindow:
             if iter is not None:
                 self.setup.language = model.get_value(iter, 3)
                 self.setup.print_setup()
-                gettext.translation('live-installer', "/usr/share/linuxmint/locale",
+                gettext.translation('live-installer', "/usr/share/pearllinux/locale",
                                 languages=[self.setup.language, self.setup.language.split('_')[0]],
                                 fallback=True).install()  # Try e.g. zh_CN, zh, or fallback to hardcoded English
                 try:
@@ -792,7 +792,7 @@ class InstallerWindow:
                             ErrorDialog(_("Installation Tool"), _("Please indicate a filesystem to format the root (/) partition with before proceeding."))
                             return
                 if not found_root_partition:
-                    ErrorDialog(_("Installation Tool"), "<b>%s</b>" % _("Please select a root (/) partition."), _("A root partition is needed to install Linux Mint on.\n\n - Mount point: /\n - Recommended size: 30GB\n - Recommended filesystem format: ext4\n "))
+                    ErrorDialog(_("Installation Tool"), "<b>%s</b>" % _("Please select a root (/) partition."), _("A root partition is needed to install Pearl Linux on.\n\n - Mount point: /\n - Recommended size: 30GB\n - Recommended filesystem format: ext4\n "))
                     return
 
                 if self.setup.gptonefi:
