@@ -14,7 +14,7 @@ import parted
 import commands
 import gettext
 
-gettext.install("live-installer", "/usr/share/linuxmint/locale")
+gettext.install("live-installer", "/usr/share/pearllinux/locale")
 
 def shell_exec(command):
     return subprocess.Popen(command, shell=True, stdout=subprocess.PIPE)
@@ -423,8 +423,8 @@ class Partition(object):
             self.free_space = to_human_readable(int(free)*1024)  # df returns values in 1024B-blocks by default
             self.used_percent = self.used_percent.strip('%') or 0
             description = ''
-            if path_exists(mount_point, 'etc/linuxmint/info'):
-                description = getoutput("cat %s/etc/linuxmint/info | grep GRUB_TITLE" % mount_point).replace('GRUB_TITLE', '').replace('=', '').replace('"', '').strip()
+            if path_exists(mount_point, 'etc/pearllinux/info'):
+                description = getoutput("cat %s/etc/pearllinux/info | grep GRUB_TITLE" % mount_point).replace('GRUB_TITLE', '').replace('=', '').replace('"', '').strip()
             elif path_exists(mount_point, 'Windows/servicing/Version'):
                 description = 'Windows ' + {
                     '6.4':'10',
@@ -447,7 +447,7 @@ class Partition(object):
                 description = 'Mac OS X'
             elif path_exists(mount_point, 'etc/'):
                 description = getoutput("su -c '{{ . {0}/etc/lsb-release && echo $DISTRIB_DESCRIPTION; }} || \
-                                                {{ . {0}/etc/os-release && echo $PRETTY_NAME; }}' mint".format(mount_point)) or 'Unix'
+                                                {{ . {0}/etc/os-release && echo $PRETTY_NAME; }}' pearl".format(mount_point)) or 'Unix'
             else:
                 try:
                     if partition.active:
@@ -532,4 +532,4 @@ class PartitionDialog(object):
         mount_as = w.child.get_text().strip()
         w = self.dTree.get_widget("combobox_use_as")
         format_as = w.get_model()[w.get_active()][0]
-        return mount_as, format_as
\ No newline at end of file
+        return mount_as, format_as
